==> aws-android-sdk-iot-2.7.4-sources.jar: com/amazonaws/services/iot/model/transform/GetIndexingConfigurationResultJsonUnmarshaller.java <==
/*
 * Copyright 2010-2018 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.iot.model.transform;

import com.amazonaws.services.iot.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;
import com.amazonaws.util.json.AwsJsonReader;

/**
 * JSON unmarshaller for response GetIndexingConfigurationResult
 */
public class GetIndexingConfigurationResultJsonUnmarshaller implements
        Unmarshaller<GetIndexingConfigurationResult, JsonUnmarshallerContext> {

    public GetIndexingConfigurationResult unmarshall(JsonUnmarshallerContext context)
            throws Exception {
        GetIndexingConfigurationResult getIndexingConfigurationResult = new GetIndexingConfigurationResult();

        AwsJsonReader reader = context.getReader();
        reader.beginObject();
        while (reader.hasNext()) {
            String name = reader.nextName();
            if (name.equals("thingIndexingConfiguration")) {
                getIndexingConfigurationResult
                        .setThingIndexingConfiguration(ThingIndexingConfigurationJsonUnmarshaller
                                .getInstance()
                                .unmarshall(context));
            } else {
                reader.skipValue();
            }
        }
        reader.endObject();

        return getIndexingConfigurationResult;
    }

    private static GetIndexingConfigurationResultJsonUnmarshaller instance;

    public static GetIndexingConfigurationResultJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new GetIndexingConfigurationResultJsonUnmarshaller();
        return instance;
    }
}

==> aws-android-sdk-iot-2.16.3-sources.jar: com/amazonaws/services/iot/model/transform/GetIndexingConfigurationResultJsonUnmarshaller.java <==
/*
 * Copyright 2010-2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.iot.model.transform;

import com.amazonaws.services.iot.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;
import com.amazonaws.util.json.AwsJsonReader;

/**
 * JSON unmarshaller for response GetIndexingConfigurationResult
 */
public class GetIndexingConfigurationResultJsonUnmarshaller implements
        Unmarshaller<GetIndexingConfigurationResult, JsonUnmarshallerContext> {

    public GetIndexingConfigurationResult unmarshall(JsonUnmarshallerContext context)
            throws Exception {
        GetIndexingConfigurationResult getIndexingConfigurationResult = new GetIndexingConfigurationResult();

        AwsJsonReader reader = context.getReader();
        reader.beginObject();
        while (reader.hasNext()) {
            String name = reader.nextName();
            if (name.equals("thingIndexingConfiguration")) {
                getIndexingConfigurationResult
                        .setThingIndexingConfiguration(ThingIndexingConfigurationJsonUnmarshaller
                                .getInstance()
                                .unmarshall(context));
            } else if (name.equals("thingGroupIndexingConfiguration")) {
                getIndexingConfigurationResult
                        .setThingGroupIndexingConfiguration(ThingGroupIndexingConfigurationJsonUnmarshaller
                                .getInstance()
                                .unmarshall(context));
            } else {
                reader.skipValue();
            }
        }
        reader.endObject();

        return getIndexingConfigurationResult;
    }

    private static GetIndexingConfigurationResultJsonUnmarshaller instance;

    public static GetIndexingConfigurationResultJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new GetIndexingConfigurationResultJsonUnmarshaller();
        return instance;
    }
}
